@@ -21,7 +21,7 @@ import fuzzywuzzy
 from fuzzywuzzy import fuzz
 from fuzzywuzzy import process
 import timeit
-from spacetag_schema import SpaceModel
+from .spacetag_schema import SpaceModel
 
 
 if not sys.warnoptions:
@@ -151,11 +151,11 @@ def ping_isi(country_list: list):
         response = requests.get(endpoint)
          resp = response.json()
 
-        
+
     except Exception as e:
         print(e)
     """
-    
+
 
 def match_geo_names(admin: str, df: pd.DataFrame) -> pd.DataFrame:
     """
@@ -173,7 +173,7 @@ def match_geo_names(admin: str, df: pd.DataFrame) -> pd.DataFrame:
     Result
     ------
     A pandas.Dataframe produced by modifying the parameter df.
-    
+
 
     Examples
     --------
@@ -191,7 +191,7 @@ def match_geo_names(admin: str, df: pd.DataFrame) -> pd.DataFrame:
 
     #start_time = timeit.default_timer()
 
-    if admin == "admin2":        
+    if admin == "admin2":
         gadm_fn = f"gadm36_2.feather"
     else:
         gadm_fn = f"gadm36_3.feather"
@@ -209,7 +209,7 @@ def match_geo_names(admin: str, df: pd.DataFrame) -> pd.DataFrame:
     else:
         gadm["admin3"] = gadm["NAME_3"]
         gadm = gadm[["country", "state", "admin1", "admin2", "admin3"]]
-        
+
     #print('load time', timeit.default_timer() - start_time)
     #start_time = timeit.default_timer()
 
@@ -217,12 +217,12 @@ def match_geo_names(admin: str, df: pd.DataFrame) -> pd.DataFrame:
     countries = df["country"].unique()
     gadm = gadm[gadm["country"].isin(countries)]
 
-    for c in countries: 
+    for c in countries:
         # The following ignores admin1 / admin2 pairs; it only cares if those
         # values exist for the appropriate country.
 
-        # Get list of admin1 values in df but not in gadm. Reduce list for country.           
-        admin1_list = gadm[gadm.country==c]["admin1"].unique()    
+        # Get list of admin1 values in df but not in gadm. Reduce list for country.
+        admin1_list = gadm[gadm.country==c]["admin1"].unique()
         if admin1_list is not None and all(admin1_list) and 'admin1' in df:
             unknowns = df[(df.country == c) & ~df.admin1.isin(admin1_list)].admin1.tolist()
             unknowns = [x for x in unknowns if pd.notnull(x) and x.strip()] # remove Nan
@@ -231,7 +231,7 @@ def match_geo_names(admin: str, df: pd.DataFrame) -> pd.DataFrame:
                 if match != None:
                     df.loc[df.admin1 == unk, 'admin1'] = match[0]
 
-        # Get list of admin2 values in df but not in gadm. Reduce list for country.           
+        # Get list of admin2 values in df but not in gadm. Reduce list for country.
         admin2_list = gadm[gadm.country==c ]["admin2"].unique()
         if admin2_list is not None and all(admin2_list) and 'admin2' in df:
             unknowns = df[(df.country == c) & ~df.admin2.isin(admin2_list)].admin2.tolist()
@@ -242,18 +242,18 @@ def match_geo_names(admin: str, df: pd.DataFrame) -> pd.DataFrame:
                     df.loc[df.admin2 == unk, 'admin2'] = match[0]
 
         if admin =='admin3':
-            # Get list of admin3 values in df but not in gadm. Reduce list for country.           
-            admin3_list = gadm[gadm.country==c]["admin3"].unique()       
+            # Get list of admin3 values in df but not in gadm. Reduce list for country.
+            admin3_list = gadm[gadm.country==c]["admin3"].unique()
             if admin3_list is not None and all(admin3_list) and 'admin3' in df:
                 unknowns = df[(df.country == c) & ~df.admin3.isin(admin3_list)].admin3.tolist()
                 unknowns = [x for x in unknowns if pd.notnull(x) and x.strip()] # remove Nan
-                for unk in unknowns:                
+                for unk in unknowns:
                     match = fuzzywuzzy.process.extractOne(unk, admin3_list, scorer=fuzz.ratio)
                     if match != None:
                         df.loc[df.admin3 == unk, 'admin3'] = match[0]
-    
+
     #print('processing time', timeit.default_timer() - start_time)
-        
+
     return df
 
 def geocode(
@@ -332,10 +332,10 @@ def generate_timestamp(series, date_mapper, column_name):
     """
     Description
     -----------
-    Generates a pandas series in M/D/Y H:M format from collected Month, Day, 
-    Year, Hour, Minute values in a parameter pandas series. Fills Month, Day, 
-    Year, Hour, Minute if missing, but at least one should be present to 
-    generate the value. Used to generate a timestamp in the absence of one in 
+    Generates a pandas series in M/D/Y H:M format from collected Month, Day,
+    Year, Hour, Minute values in a parameter pandas series. Fills Month, Day,
+    Year, Hour, Minute if missing, but at least one should be present to
+    generate the value. Used to generate a timestamp in the absence of one in
     the data.
 
     Parameters
@@ -348,7 +348,7 @@ def generate_timestamp(series, date_mapper, column_name):
     column_name: str
         name of the new column e.g. timestamp for primary_time, year1month1day1
         for a concatneated name from associated date fields.
-        
+
     Examples
     --------
     This example adds the generated series to the source dataframe.
@@ -420,15 +420,15 @@ def normalizer(df: pd.DataFrame, mapper: dict, admin: str) -> pd.DataFrame:
         a dict where keys will be geo, feaure, date, and values will be lists of dict
         example:
         { 'geo': [
-             {'name': 'country', 'type': 'geo', 'geo_type': 'country', 'primary_geo': False}, 
+             {'name': 'country', 'type': 'geo', 'geo_type': 'country', 'primary_geo': False},
              {'name': 'state', 'type': 'geo', 'geo_type': 'state/territory', 'primary_geo': False}
-           ], 
+           ],
            'feature': [
-              {'name': 'probabilty', 'type': 'feature', 'feature_type': 'float'}, 
+              {'name': 'probabilty', 'type': 'feature', 'feature_type': 'float'},
               {'name': 'color', 'type': 'feature', 'feature_type': 'str'}
-            ], 
+            ],
             'date': [
-               {'name': 'date_2', 'type': 'date', 'date_type': 'date', 'primary_date': False, 'time_format': '%m/%d/%y'}, 
+               {'name': 'date_2', 'type': 'date', 'date_type': 'date', 'primary_date': False, 'time_format': '%m/%d/%y'},
                {'name': 'date', 'type': 'date', 'date_type': 'date', 'primary_date': True, 'time_format': '%m/%d/%y'}
             ]
         }
@@ -463,7 +463,7 @@ def normalizer(df: pd.DataFrame, mapper: dict, admin: str) -> pd.DataFrame:
 
     # mapper is a dictionary of lists of dictionaries.
     primary_time_cols = [k['name'] for k in mapper['date'] if 'primary_date' in k and k['primary_date'] == True]
-    other_time_cols   = [k['name'] for k in mapper['date'] if 'primary_date' not in k or k['primary_date'] == False]   
+    other_time_cols   = [k['name'] for k in mapper['date'] if 'primary_date' not in k or k['primary_date'] == False]
     primary_geo_cols  = [k["name"] for k in mapper["geo"]  if "primary_geo"  in k and k["primary_geo"] == True]
 
     # dictionary for columns qualified by another column.
@@ -501,14 +501,14 @@ def normalizer(df: pd.DataFrame, mapper: dict, admin: str) -> pd.DataFrame:
             elif date_dict["date_type"] in ["day","month","year"]:
                 primary_date_group_mapper[kk] = date_dict
         elif "qualifies" in date_dict and date_dict["qualifies"]:
-            # Note that any "qualifier" column that is not primary geo/date 
-            # will just be lopped on to the right as its own column. It's 
-            # column name will just be the name and Uncharted will deal with 
-            # it. The key takeaway is that qualifier columns grow the width, 
+            # Note that any "qualifier" column that is not primary geo/date
+            # will just be lopped on to the right as its own column. It's
+            # column name will just be the name and Uncharted will deal with
+            # it. The key takeaway is that qualifier columns grow the width,
             # not the length of the dataset.
             # Want to add the qualified col as the dictionary key.
             # e.g. "name": "region", "qualifies": ["probability", "color"]
-            # should produce two dict entries for prob and color, with region 
+            # should produce two dict entries for prob and color, with region
             # in a list as the value for both.
             for k in date_dict["qualifies"]:
                 if k in qualified_col_dict:
@@ -516,23 +516,23 @@ def normalizer(df: pd.DataFrame, mapper: dict, admin: str) -> pd.DataFrame:
                 else:
                     qualified_col_dict[k] = [kk]
 
-        else:            
+        else:
             if kk in other_time_cols and date_dict["date_type"] == "date":
                 # Convert all date/time to epoch time if not already.
-                df[kk] = df[kk].apply(lambda x: format_time(str(x), date_dict["time_format"], validate=False))                
+                df[kk] = df[kk].apply(lambda x: format_time(str(x), date_dict["time_format"], validate=False))
                 # If three are no assigned primary_time columns, make this the
                 # primary_time timestamp column, and keep as a feature so the
                 # column_name meaning is not lost.
                 if not primary_time_cols and not "timestamp" in df.columns:
                     df.rename(columns={kk: "timestamp"}, inplace=True)
             elif date_dict["date_type"] in ["day","month","year"] and 'associated_columns' in date_dict:
-                # Various date columns have been associated by the user and are not primary_date. 
-                # convert them to epoch then store them as a feature 
-                # (instead of storing them as separate uncombined features). 
+                # Various date columns have been associated by the user and are not primary_date.
+                # convert them to epoch then store them as a feature
+                # (instead of storing them as separate uncombined features).
                 other_date_group_mapper[kk] = date_dict
                 continue
             # All not primary_time, not associated_columns fields are pushed to features.
-            features.append(kk)  
+            features.append(kk)
 
     if primary_date_group_mapper:
         # Applied when there were primary_date year,month,day fields above. These need to be combined
@@ -541,7 +541,7 @@ def normalizer(df: pd.DataFrame, mapper: dict, admin: str) -> pd.DataFrame:
         df['timestamp'] = df["timestamp"].apply(lambda x: format_time(str(x), "%m/%d/%y", validate=False))
 
     while other_date_group_mapper:
-        # Various date columns have been associated by the user and are not primary_date. 
+        # Various date columns have been associated by the user and are not primary_date.
         # Convert to epoch time and store as a feature, do not store these separately in features.
         # Control for possibility of more than one set of assciated_columns.
         date_field_tuple = other_date_group_mapper.popitem()
@@ -550,9 +550,9 @@ def normalizer(df: pd.DataFrame, mapper: dict, admin: str) -> pd.DataFrame:
         assoc_columns[date_field_tuple[0]] = date_field_tuple[1]
         assoc_fields.append(date_field_tuple[0])
 
-        # If there is no primary_time column for timestamp, which would have 
+        # If there is no primary_time column for timestamp, which would have
         # been created above with primary_date_group_mapper, or farther above
-        # looping mapper["date"], attempt to generate from date_type = Month, 
+        # looping mapper["date"], attempt to generate from date_type = Month,
         # Day, Year features. Otherwise, create a new column name from the
         # concatenation of the associated date fields here.
         if not "timestamp" in df.columns:
@@ -591,29 +591,29 @@ def normalizer(df: pd.DataFrame, mapper: dict, admin: str) -> pd.DataFrame:
             elif geo_dict["geo_type"] == "country" and kk != "country":
                 # force the country column to be named country
                 staple_col_name = "country"
-                df.rename(columns={kk: staple_col_name}, inplace=True)                
+                df.rename(columns={kk: staple_col_name}, inplace=True)
         elif "qualifies" in geo_dict and geo_dict["qualifies"]:
-            # Note that any "qualifier" column that is not primary geo/date 
-            # will just be lopped on to the right as its own column. It'’'s 
-            # column name will just be the name and Uncharted will deal with 
-            # it. The key takeaway is that qualifier columns grow the width, 
+            # Note that any "qualifier" column that is not primary geo/date
+            # will just be lopped on to the right as its own column. It'’'s
+            # column name will just be the name and Uncharted will deal with
+            # it. The key takeaway is that qualifier columns grow the width,
             # not the length of the dataset.
             # Want to add the qualified col as the dictionary key.
             # e.g. "name": "region", "qualifies": ["probability", "color"]
-            # should produce two dict entries for prob and color, with region 
+            # should produce two dict entries for prob and color, with region
             # in a list as the value for both.
             for k in geo_dict["qualifies"]:
                 if k in qualified_col_dict:
                     qualified_col_dict[k].append(kk)
                 else:
-                    qualified_col_dict[k] = [kk]          
+                    qualified_col_dict[k] = [kk]
         else:
             # only push geo columns to the named columns
             # in the event there is no primary geo
             # otherwise they are features and we geocode lat/lng
             if len(primary_geo_cols) == 0:
-                if geo_dict["geo_type"] == "country":                    
-                    df["country"] = df[kk]                  
+                if geo_dict["geo_type"] == "country":
+                    df["country"] = df[kk]
                     continue
                 if geo_dict["geo_type"] == "state/territory":
                     df["admin1"] = df[kk]
@@ -622,32 +622,32 @@ def normalizer(df: pd.DataFrame, mapper: dict, admin: str) -> pd.DataFrame:
                     df["admin2"] = df[kk]
                     continue
                 if geo_dict["geo_type"] == "municipality/town":
-                    df["admin3"] = df[kk]                
+                    df["admin3"] = df[kk]
                     continue
             features.append(kk)
 
-    # Append columns annotated in feature dict to features list (if not a 
+    # Append columns annotated in feature dict to features list (if not a
     # qualifies column)
     #features.extend([k["name"] for k in mapper["feature"]])
     for feature_dict in mapper["feature"]:
         if "qualifies" not in feature_dict or not feature_dict["qualifies"]:
             features.append(feature_dict["name"])
-        elif "qualifies" in feature_dict and feature_dict["qualifies"]: 
-            # Note that any "qualifier" column that is not primary geo/date 
-            # will just be lopped on to the right as its own column. It's 
-            # column name will just be the name and Uncharted will deal with 
-            # it. The key takeaway is that qualifier columns grow the width, 
+        elif "qualifies" in feature_dict and feature_dict["qualifies"]:
+            # Note that any "qualifier" column that is not primary geo/date
+            # will just be lopped on to the right as its own column. It's
+            # column name will just be the name and Uncharted will deal with
+            # it. The key takeaway is that qualifier columns grow the width,
             # not the length of the dataset.
             # Want to add the qualified col as the dictionary key.
             # e.g. "name": "region", "qualifies": ["probability", "color"]
-            # should produce two dict entries for prob and color, with region 
+            # should produce two dict entries for prob and color, with region
             # in a list as the value for both.
             for k in feature_dict["qualifies"]:
                 kk = feature_dict["name"]
                 if k in qualified_col_dict:
                     qualified_col_dict[k].append(kk)
                 else:
-                    qualified_col_dict[k] = [kk]       
+                    qualified_col_dict[k] = [kk]
 
     # perform geocoding if lat/lng are present
     if "lat" in df and "lng" in df:
@@ -659,7 +659,7 @@ def normalizer(df: pd.DataFrame, mapper: dict, admin: str) -> pd.DataFrame:
     df_geo_cols = [i for i in df.columns if 'mixmasta_geocoded' in i]
     for c in df_geo_cols:
         df.rename(columns={c: c.replace('_mixmasta_geocoded','')}, inplace=True)
-    
+
 
     # protected_cols are the required_cols present in the submitted dataframe.
     protected_cols = list(set(required_cols) & set(df.columns))
@@ -685,13 +685,13 @@ def normalizer(df: pd.DataFrame, mapper: dict, admin: str) -> pd.DataFrame:
             # dict value is a list, so extend.
             using_cols.extend(qualified_col_dict[feat])
             col_order.extend(qualified_col_dict[feat])
-        
+
         join_overlap = False
         try:
             df_ = df[using_cols + [feat+'_mixmasta_left']].copy()
             join_overlap = True
-        except:            
-            df_ = df[using_cols + [feat]].copy()            
+        except:
+            df_ = df[using_cols + [feat]].copy()
 
         try:
             if mapper[feat]["new_col_name"] == None:
@@ -706,7 +706,7 @@ def normalizer(df: pd.DataFrame, mapper: dict, admin: str) -> pd.DataFrame:
         else:
             df_.rename(columns={feat: "value"}, inplace=True)
 
-        
+
         # Add feature/value for epochtime as object adds it without decimal
         # places, but it is still saved as a double in the parquet file.
         if len(df_out) == 0:
@@ -723,7 +723,7 @@ def normalizer(df: pd.DataFrame, mapper: dict, admin: str) -> pd.DataFrame:
     for c in col_order:
         if c not in df_out:
             df_out[c] = None
-    
+
     return df_out[col_order]
 
 
@@ -771,11 +771,11 @@ def process(fp: str, mp: str, admin: str, output_file: str):
     norm = normalizer(df, mapper, admin)
 
     # Separate string values from others
-    norm['type'] = norm[['value']].applymap(type)   
+    norm['type'] = norm[['value']].applymap(type)
     norm_str = norm[norm['type']==str]
     norm = norm[norm['type']!=str]
     del(norm_str['type'])
-    del(norm['type'])    
+    del(norm['type'])
 
     # Testing
     """print('\n', norm.head(50))
@@ -793,5 +793,5 @@ mp = 'examples/causemosify-tests/test_file_5_schema2.json'
 fp = 'examples/causemosify-tests/test_file_5_schema2.csv'
 geo = 'admin3'
 outf = 'examples/causemosify-tests/test_file_5_schema2'
-process(fp, mp, geo, outf) 
+process(fp, mp, geo, outf)
 """
\ No newline at end of file
